@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql-server/src/backend/port/qnx4/tstsem.c,v 1.8 2002/09/04 20:31:24 momjian Exp $
+ *	  $Header: /cvsroot/pgsql-server/src/backend/port/qnx4/tstsem.c,v 1.9 2002/11/08 20:23:56 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -15,8 +15,6 @@
 #include "postgres.h"
 
 #include <signal.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <unistd.h>
 #include "storage/ipc.h"
 #include <sys/mman.h>
