@@ -4,12 +4,12 @@
  *	  routines for manipulating the buffer pool's replacement strategy
  *	  freelist.
  *
- * Portions Copyright (c) 1996-2001, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2003, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql/src/backend/storage/buffer/freelist.c,v 1.28 2001/11/05 17:46:27 momjian Exp $
+ *	  $Header: /cvsroot/pgsql-server/src/backend/storage/buffer/freelist.c,v 1.31 2003/08/04 02:40:03 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -198,7 +198,9 @@ GetFreeBuffer(void)
 	if (Free_List_Descriptor == SharedFreeList->freeNext)
 	{
 		/* queue is empty. All buffers in the buffer pool are pinned. */
-		elog(ERROR, "out of free buffers: time to abort!");
+		ereport(ERROR,
+				(errcode(ERRCODE_INSUFFICIENT_RESOURCES),
+				 errmsg("out of free buffers")));
 		return NULL;
 	}
 	buf = &(BufferDescriptors[SharedFreeList->freeNext]);
